momori(data,mag=NULL,threshold=0.0,tstart,tend,parami,tmpfile=NULL, nlmax=1000)parai, momori() repeats calculations of function values and its gradients at each step of parameter vector.
At each cycle of iteration, the linearly searched step ($lambda$), negative log-likelihood value ($-LL$),
and two estimates of square sum of gradients are shown ($process=1$).
The cumulative number of earthquakes at time $t$ since $t_0$ is given by the integration of $f(t)$ with respect to the time $t$,
$$F(t) = B(t-t_0) + K{c^{1-p}-(t-t_i+c)^{1-p}} / (p-1)$$
where the summation of $i$ is taken for all data event.data(main2003JUL26) # The aftershock data of 26th July 2003 earthquake of M6.2
x <- main2003JUL26
momori(x$time, x$magnitude, 2.5, 0.01, 18.68,
c(0,0.96021E+02,0.58563E-01,0.96611E+00))Run the code above in your browser using DataLab